@@ -1,6 +1,6 @@
-#!/usr/bin/python3 -i
+#!/usr/bin/env python3 -i
 #
-# Copyright (c) 2017-2024, The Khronos Group Inc.
+# Copyright (c) 2017-2025 The Khronos Group Inc.
 # Copyright (c) 2017-2019 Valve Corporation
 # Copyright (c) 2017-2019 LunarG, Inc.
 #
@@ -583,7 +583,7 @@ class AutomaticSourceOutputGenerator(OutputGenerator):
     # overridden by a derived class.
     #   self            the AutomaticSourceOutputGenerator object
     def outputCopywriteHeader(self):
-        notice = '// Copyright (c) 2017-2024, The Khronos Group Inc.\n'
+        notice = '// Copyright (c) 2017-2025 The Khronos Group Inc.\n'
         notice += '// Copyright (c) 2017-2019 Valve Corporation\n'
         notice += '// Copyright (c) 2017-2019 LunarG, Inc.\n'
         notice += '//\n'
@@ -848,11 +848,6 @@ class AutomaticSourceOutputGenerator(OutputGenerator):
                     (protect_value, protect_string) = self.genProtectInfo(
                         self.featureExtraProtect, elem.get('protect'))
                     if item_name is not None:
-                        if len(item_name) + 1 > self.max_structure_type_length:
-                            self.printCodeGenErrorMessage('StructureType %s length %d in XML (for'
-                                                          ' extension %s) is greater than allowable'
-                                                          ' space of %d when null-terminator is added' % (
-                                                              item_name, len(item_name), self.currentExtension, self.max_structure_type_length))
                         if is_extension and not item_name.endswith(self.current_vendor_tag):
                             self.printCodeGenErrorMessage('StructureType %s in XML (for extension'
                                                           ' %s) does not end with the expected'
